Générer des fichiers de cas — Documentation audiometry_trainer 0.1.16

# Générer des fichiers de cas

Pour générer un nouveau cas cliquez sur le menu `Fichier` et en suite sur `Générer un cas`. La fenêtre de `génération de cas` s’ouvrira. Les cas sont générés sur la base des paramètres de courbe psychométrique (CP) pour les seuils de conduction osseuse (CO) et du Rinne. Les paramètres de CP pour les réponses en conduction aérienne (CA) sont générés en interne par le logiciel sur la base des paramètres de CO et du Rinne. Par exemple, le point médian de la CP en CA est égal au point médian de la CB en CO plus le Rinne. Le taux de fausses alarmes, ainsi que le taux d’inattention, sont présumés être les mêmes que ceux des réponses en CO. Quand vous générez un cas, les seuils d’un sujet virtuel son simulés sur des nombreuses itérations pour obtenir le seuils médians et les intervalles de confiance de 95% qui sont affichés lorsque vous cliquez les cases à cocher `Affichage des vrais seuils` dans la fenêtre principale de `audiometry_trainer`. Veulliez consulter la Séction Sujet virtuel pour plus de détails sur les CPs.

Les paramètres du sujet virtuel sont spécifiés à travers une interface en tableau dans laquelle chaque ligne représente une fréquence différente. Les fréquences peuvent être ajoutés/enlevés en cliquant sur le menu `Éditer` et ensuite sur `Fréquences`. Seulement un nombre limité de fréquences entre 0,125 et 8 kHz peut être utilisé. En sélectionnant avec la souris plusieurs cellules et ensuite cliquant droit on peut copier/couper/coller les valeurs des cellules ainsi que éditer toutes les cellules sélectionnés avec la même valeur.

Les noms de colonnes du tableur de la fenêtre `générer un cas` utilisent des abréviations pour des raisons d’espace : pnt. méd pour point médian, oss. pour osseuse, F.A. pour fausses alarmes, inatt pour inattention, D pour droite et G pour gauche. Pour donnes quelques exemples d’utilisation concrète, si vous souhaitez simuler une perte auditive neurosensorielle de 45 dB HL à une certaine fréquence vous pouvez fixer le point médian de la CP de CO autour de 43 dB HL, la largeur de la CB autour de 8 dB, et le rinne à zéro. Le point médian est le point auquel le sujet répond « Oui » 50% des fois (en supposant des taux de F.A. et d’inattention proches de zéro). Le seuil qu’on retrouve avec la procédure d’Hugson-Westlake se situe sur un pourcentage de réponses « Oui » entre 50% et 100%. Une largeur de 8 dB signifie que la CP ira de 5% à 95% dans l’espace de 8 dB, par conséquent elle ira du point médian (43 dB HL) à 95% de réponses « Oui » dans l’espace de 4 dB (la moitié de la largeur). Globalement, en utilisant ces paramètres le seuil se situera à 2 dB près de 45 dB HL. Vue que la taille de pas utilisée pour la recherche du seuil est de 5 dB, le seuil qu’en résultera se situera presque certainement, en moyenne, à 45 dB HL. Ceci est juste un exemple et des variations de chacun des paramètres de la CP (point médian, largeur, taux de F.A. et taux d’inattention) pourraient êtres employées pour obtenir des sujets virtuels avec le même seuils mais un comportement différent. Empiriquement, la région d’incertitude entre inaudibilité et détection certaine dans l’audiométrie clinique a été estimé être d’une largeur d’environ 10 dB [Barr-HamiltonEtAl1969], donc des largeurs de CP d’environ 10 dB devrait résulter en des sujets virtuel assez réalistes.

Pour simuler une perte de transmission/mixte vous pouvez simplement fixer le Rinne à la valeur souhaitée de la composante de transmission. Le point médian de la CP de CA sera déplacé de la taille du Rinne par rapport au point médian de la CP de CO.

En plus des paramètres de CP en CO et du Rinne il y a deux colonnes, `Gain D` et `Gain G` qui représentent le gain d’un appareil auditif utilisé par le sujet virtuel. Les valeurs dans ces deux colonnes n’ont aucun effet sur les réponses du sujet virtuel obtenues avec un casque ou par conduction osseuse. Ces valeurs ont une influence seulement sur les réponses en champ libre. Pour l’instant les réponse en champ libre ne sont pas disponibles sur `audiometry_trainer` mais elles pourraient être codées dans des versions futures du logiciel, donc pour l’instant vous pouvez laisser les valeurs des colonnes `Gain D` et `Gain G` à leur valeur par défaut de zéro.

Lorsque vous êtes satisfait avec la saisie des paramètres du sujet virtuel, vous pouvez éditer le nombre de simulations souhaitées dans la case `No. de simulations` et ensuite cliquer sur le bouton `Exécuter la simulation`. Vous serez invités à sélectionner le fichier dans lequel les résultats seront sauvegardés. Pour utiliser le fichier de cas que vous avez généré dans `audiometry_trainer` vous pouvez simplement le charger dans la fenêtre principale de `audiometry_trainer` en cliquant sur le menu `Fichier` et ensuite sur `Charger un cas`.

De façon facultative, une graine aléatoire peut être saisi pour obtenir des résultats reproductibles. En plus, des information sur le cas (par ex. le type de perte auditive, la source du cas, etc.) peuvent être ajoutés dans la case `Info du cas`. La syntaxe de Markdown peut être utilisée dans cette case et elle sera affichée convenablement lorsque l’information de cas sera chargé dans `audiometry_trainer`. L’information du cas est sauvegardée dans un fichier d’info du cas qui est enregistré de façon automatique quand la simulation est exécutée, même si vous laissez la case d’info vide. Le nom de ce fichier d’info du cas aura la même racine que le fichier du cas mais se terminera avec le suffixe `_info.md`. Pour que l’info du cas soit chargée par `audiometry_trainer` lorsque vous charger un fichier de cas, le fichier d’info du cas doit se trouver dans le même dossier du fichier du cas.

Les paramètres du sujet virtuel peuvent être enregistré pour ensuite être chargés à nouveau dans la fenêtre `générer un cas` en cliquant sur les actions `Sauvegarder les paramètres` et `Charger les paramètres` qui se trouvent sous le menu `Fichier`. Lorsque vous enregistré un fichier de paramètres, le texte qui se trouve dans la case `Info du cas` est enregistré dans un fichier de l’info du cas. Lorsque vous chargez un fichier de paramètres, le fichier de l’info du cas sera lui aussi chargé s’il se trouve dans le même dossier que le fichier de paramètres.